<?php
/**
 * VW Education Lite Theme Customizer
 *
 * @package VW Education Lite
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function vw_education_lite_custom_controls() { 

    load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'vw_education_lite_custom_controls' );

function vw_education_lite_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . '/inc/icon-picker.php' );

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage'; 
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'blogname', array( 
		'selector' => '.logo .site-title a', 
	 	'render_callback' => 'vw_education_lite_customize_partial_blogname', 
	)); 

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array( 
		'selector' => 'p.site-description', 
		'render_callback' => 'vw_education_lite_customize_partial_blogdescription', 
	));

	//add home page setting pannel
	$VWEducationLiteParentPanel = new VW_Education_Lite_WP_Customize_Panel( $wp_customize, 'vw_education_lite_panel_id', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__( 'VW Settings', 'vw-education-lite' ),
		'priority' => 10,
	));
	$wp_customize->add_panel( $VWEducationLiteParentPanel );

	$HomePageParentPanel = new VW_Education_Lite_WP_Customize_Panel( $wp_customize, 'vw_education_lite_homepage_panel', array(
		'title' => __( 'Homepage Settings', 'vw-education-lite' ),
		'panel' => 'vw_education_lite_panel_id',
	));

	$wp_customize->add_panel( $HomePageParentPanel );

	// Topbar
	$wp_customize->add_section('vw_education_lite_headercont_section',array(
		'title'	=> __('Topbar','vw-education-lite'),
		'description'	=> __('Add topbar contact details here','vw-education-lite'),
		'priority'	=> null,
		'panel' => 'vw_education_lite_homepage_panel'
	));

   	// Header Background color
	$wp_customize->add_setting('vw_education_lite_header_background_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_education_lite_header_background_color', array(
		'label'    => __('Header Background Color', 'vw-education-lite'),
		'section'  => 'header_image',
	)));

	$wp_customize->add_setting('vw_education_lite_header_img_position',array(
	  'default' => 'center top',
	  'transport' => 'refresh',
	  'sanitize_callback' => 'vw_education_lite_sanitize_choices'
	));
	$wp_customize->add_control('vw_education_lite_header_img_position',array(
		'type' => 'select',
		'label' => __('Header Image Position','vw-education-lite'),
		'section' => 'header_image',
		'choices' 	=> array(
			'left top' 		=> esc_html__( 'Top Left', 'vw-education-lite' ),
			'center top'   => esc_html__( 'Top', 'vw-education-lite' ),
			'right top'   => esc_html__( 'Top Right', 'vw-education-lite' ),
			'left center'   => esc_html__( 'Left', 'vw-education-lite' ),
			'center center'   => esc_html__( 'Center', 'vw-education-lite' ),
			'right center'   => esc_html__( 'Right', 'vw-education-lite' ),
			'left bottom'   => esc_html__( 'Bottom Left', 'vw-education-lite' ),
			'center bottom'   => esc_html__( 'Bottom', 'vw-education-lite' ),
			'right bottom'   => esc_html__( 'Bottom Right', 'vw-education-lite' ),
		),
	));

	$wp_customize->add_setting( 'vw_education_lite_topbar_hide_show',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_topbar_hide_show',
       array(
		'label' => esc_html__( 'Show / Hide Topbar','vw-education-lite' ),
		'section' => 'vw_education_lite_headercont_section'
    )));

     $wp_customize->add_setting('vw_education_lite_topbar_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_topbar_padding_top_bottom',array(
		'label'	=> __('Topbar Padding Top Bottom','vw-education-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_headercont_section',
		'type'=> 'text'
	));

    //Sticky Header
	$wp_customize->add_setting( 'vw_education_lite_sticky_header',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_sticky_header',array(
        'label' => esc_html__( 'Show / Hide Sticky Header','vw-education-lite' ),
        'section' => 'vw_education_lite_headercont_section'
    )));

    $wp_customize->add_setting('vw_education_lite_sticky_header_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_sticky_header_padding',array(
		'label'	=> __('Sticky Header Padding','vw-education-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_headercont_section',
		'type'=> 'text'
	));

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_education_lite_cont_phone', array( 
		'selector' => '.top-bar .phone i', 
		'render_callback' => 'vw_education_lite_customize_partial_vw_education_lite_cont_phone', 
	));

    $wp_customize->add_setting('vw_education_lite_cont_phone_icon',array(
		'default'	=> 'fas fa-mobile-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Education_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_education_lite_cont_phone_icon',array(
		'label'	=> __('Add Contact Number Icon','vw-education-lite'),
		'transport' => 'refresh',
		'section'	=> 'vw_education_lite_headercont_section',
		'setting'	=> 'vw_education_lite_cont_phone_icon',
		'type'		=> 'icon'
	)));
	
	$wp_customize->add_setting('vw_education_lite_cont_phone',array(
		'default'	=> '',
		'sanitize_callback'	=> 'vw_education_lite_sanitize_phone_number'
	));
	
	$wp_customize->add_control('vw_education_lite_cont_phone',array(
		'label'	=> __('Add contact number','vw-education-lite'),
		'section'	=> 'vw_education_lite_headercont_section',
		'setting'	=> 'vw_education_lite_cont_phone',
		'type'	=> 'text'
	));

	$wp_customize->add_setting('vw_education_lite_cont_email_icon',array(
		'default'	=> 'far fa-envelope',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Education_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_education_lite_cont_email_icon',array(
		'label'	=> __('Add Email address Icon','vw-education-lite'),
		'transport' => 'refresh',
		'section'	=> 'vw_education_lite_headercont_section',
		'setting'	=> 'vw_education_lite_cont_email_icon',
		'type'		=> 'icon'
	)));
	
	$wp_customize->add_setting('vw_education_lite_cont_email',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_email'
	));
	
	$wp_customize->add_control('vw_education_lite_cont_email',array(
		'label'	=> __('Add email address here','vw-education-lite'),
		'section'	=> 'vw_education_lite_headercont_section',
		'setting'	=> 'vw_education_lite_cont_email',
		'type'		=> 'text'
	));

	//Menus Settings
	$wp_customize->add_section( 'vw_education_lite_menu_section' , array(
    	'title' => __( 'Menus Settings', 'vw-education-lite' ),
		'panel' => 'vw_education_lite_homepage_panel'
	) );

	$wp_customize->add_setting('vw_education_lite_navigation_menu_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_navigation_menu_font_size',array(
		'label'	=> __('Menus Font Size','vw-education-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_menu_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_education_lite_navigation_menu_font_weight',array(
        'default' => 600,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_education_lite_sanitize_choices'
	));
	$wp_customize->add_control('vw_education_lite_navigation_menu_font_weight',array(
        'type' => 'select',
        'label' => __('Menus Font Weight','vw-education-lite'),
        'section' => 'vw_education_lite_menu_section',
        'choices' => array(
        	'100' => __('100','vw-education-lite'),
            '200' => __('200','vw-education-lite'),
            '300' => __('300','vw-education-lite'),
            '400' => __('400','vw-education-lite'),
            '500' => __('500','vw-education-lite'),
            '600' => __('600','vw-education-lite'),
            '700' => __('700','vw-education-lite'),
            '800' => __('800','vw-education-lite'),
            '900' => __('900','vw-education-lite'),
        ),
	) );

	// text trasform
	$wp_customize->add_setting('vw_education_lite_menu_text_transform',array(
		'default'=> 'Uppercase',
		'sanitize_callback'	=> 'vw_education_lite_sanitize_choices'
	));
	$wp_customize->add_control('vw_education_lite_menu_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Menu Text Transform','vw-education-lite'),
		'choices' => array(
            'Uppercase' => __('Uppercase','vw-education-lite'),
            'Capitalize' => __('Capitalize','vw-education-lite'),
            'Lowercase' => __('Lowercase','vw-education-lite'),
        ),
		'section'=> 'vw_education_lite_menu_section',
	));

	$wp_customize->add_setting('vw_education_lite_menus_item_style',array(
        'default' => '',
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_education_lite_sanitize_choices'
	));
	$wp_customize->add_control('vw_education_lite_menus_item_style',array(
        'type' => 'select',
        'section' => 'vw_education_lite_menu_section',
		'label' => __('Menu Item Hover Style','vw-education-lite'),
		'choices' => array(
            'None' => __('None','vw-education-lite'),
            'Zoom In' => __('Zoom In','vw-education-lite'),
        ),
	) );

	$wp_customize->add_setting('vw_education_lite_header_menus_color', array(
		'default'           => '#222',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_education_lite_header_menus_color', array(
		'label'    => __('Menus Color', 'vw-education-lite'),
		'section'  => 'vw_education_lite_menu_section',
	)));

	$wp_customize->add_setting('vw_education_lite_header_menus_hover_color', array(
		'default'           => '#222',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_education_lite_header_menus_hover_color', array(
		'label'    => __('Menus Hover Color', 'vw-education-lite'),
		'section'  => 'vw_education_lite_menu_section',
	)));

	$wp_customize->add_setting('vw_education_lite_header_submenus_color', array(
		'default'           => '#222',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_education_lite_header_submenus_color', array(
		'label'    => __('Sub Menus Color', 'vw-education-lite'),
		'section'  => 'vw_education_lite_menu_section',
	)));

	$wp_customize->add_setting('vw_education_lite_header_submenus_hover_color', array(
		'default'           => '#99ce34',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_education_lite_header_submenus_hover_color', array(
		'label'    => __('Sub Menus Hover Color', 'vw-education-lite'),
		'section'  => 'vw_education_lite_menu_section',
	)));

	//Social links
	$wp_customize->add_section(
		'vw_education_lite_social_links', array(
			'title'		=>	__('Social Links', 'vw-education-lite'),
			'priority'	=>	null,
			'panel'		=>	'vw_education_lite_homepage_panel'
		)
	);

	$wp_customize->add_setting('vw_education_lite_social_icons',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_social_icons',array(
		'label' =>  __('Steps to setup social icons','vw-education-lite'),
		'description' => __('<p>1. Go to Dashboard >> Appearance >> Widgets</p>
			<p>2. Add Vw Social Icon Widget in Social Icon Widget area.</p>
			<p>3. Add social icons url and save.</p>','vw-education-lite'),
		'section'=> 'vw_education_lite_social_links',
		'type'=> 'hidden'
	));
	$wp_customize->add_setting('vw_education_lite_social_icon_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_social_icon_btn',array(
		'description' => "<a target='_blank' href='". admin_url('widgets.php') ." '>Setup Social Icons</a>",
		'section'=> 'vw_education_lite_social_links',
		'type'=> 'hidden'
	));

	//home page slider
	$wp_customize->add_section( 'vw_education_lite_slidersettings' , array(
      	'title'      => __( 'Slider Settings', 'vw-education-lite' ),
      	'description' => __('Free theme has 3 slides options, For unlimited slides and more options </br> <a class="go-pro-btn" target="blank" href="http://www.vwthemes.com/themes/vw-education-theme/">GET PRO</a>','vw-education-lite'),
	    'priority'   => null,
	    'panel' => 'vw_education_lite_homepage_panel'
	  ) );

	$wp_customize->add_setting( 'vw_education_lite_slider_hide_show',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_slider_hide_show',
       array(
		'label' => esc_html__( 'Show / Hide Slider','vw-education-lite' ),
		'section' => 'vw_education_lite_slidersettings'
    )));

    $wp_customize->add_setting('vw_education_lite_slider_type',array(
        'default' => 'Default slider',
        'sanitize_callback' => 'vw_education_lite_sanitize_choices'
	) );
	$wp_customize->add_control('vw_education_lite_slider_type', array(
        'type' => 'select',
        'label' => __('Slider Type','vw-education-lite'),
        'section' => 'vw_education_lite_slidersettings',
        'choices' => array(
            'Default slider' => __('Default slider','vw-education-lite'),
            'Advance slider' => __('Advance slider','vw-education-lite'),
        ),
	));

	$wp_customize->add_setting('vw_education_lite_advance_slider_shortcode',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_advance_slider_shortcode',array(
		'label'	=> __('Add Slider Shortcode','vw-education-lite'),
		'section'=> 'vw_education_lite_slidersettings',
		'type'=> 'text',
		'active_callback' => 'vw_education_lite_advance_slider'
	));

    //Selective Refresh
    $wp_customize->selective_refresh->add_partial('vw_education_lite_slider_hide_show',array(
		'selector'        => '#slider .inner_carousel h1',
		'render_callback' => 'vw_education_lite_customize_partial_vw_education_lite_slider_hide_show',
	));

	for ( $count = 1; $count <= 3; $count++ ) {
	    // Add color scheme setting and control.
	    $wp_customize->add_setting( 'vw_education_lite_slider_page' . $count, array(
	      'default'           => '',
	      'sanitize_callback' => 'vw_education_lite_sanitize_dropdown_pages'
	    ) );
	    $wp_customize->add_control( 'vw_education_lite_slider_page' . $count, array(
	      'label'    => __( 'Select Slide Image Page', 'vw-education-lite' ),
	      'description' => __('Slider image size (1500 x 765)','vw-education-lite'),
	      'section'  => 'vw_education_lite_slidersettings',
	      'type'     => 'dropdown-pages',
	      'active_callback' => 'vw_education_lite_default_slider'
	    ) );
  	}

  	$wp_customize->add_setting('vw_education_lite_slider_button_text',array(
		'default'=> 'Know More',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_slider_button_text',array(
		'label'	=> __('Add Slider Button Text','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Know More', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_slidersettings',
		'type'=> 'text',
		'active_callback' => 'vw_education_lite_default_slider'
	));

	$wp_customize->add_setting('vw_education_lite_slider_button_link',array(
        'default'=> '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('vw_education_lite_slider_button_link',array(
        'label' => esc_html__('Add Button Link','vw-education-lite'),
        'input_attrs' => array(
            'placeholder' => esc_html__( 'www.example-info.com', 'vw-education-lite' ),
        ),
        'section'=> 'vw_education_lite_slidersettings',
        'type'=> 'url'
    ));

  	//content layout
	$wp_customize->add_setting('vw_education_lite_slider_content_option',array(
        'default' => 'Center',
        'sanitize_callback' => 'vw_education_lite_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Education_Lite_Image_Radio_Control($wp_customize, 'vw_education_lite_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','vw-education-lite'),
        'section' => 'vw_education_lite_slidersettings',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/images/slider-content1.png',
            'Center' => esc_url(get_template_directory_uri()).'/images/slider-content2.png',
            'Right' => esc_url(get_template_directory_uri()).'/images/slider-content3.png',
    ),'active_callback' => 'vw_education_lite_default_slider'
    )));

    //Slider content padding
    $wp_customize->add_setting('vw_education_lite_slider_content_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_slider_content_padding_top_bottom',array(
		'label'	=> __('Slider Content Padding Top Bottom','vw-education-lite'),
		'description'	=> __('Enter a value in %. Example:20%','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( '50%', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_slidersettings',
		'type'=> 'text',
		'active_callback' => 'vw_education_lite_default_slider'
	));

	$wp_customize->add_setting('vw_education_lite_slider_content_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_slider_content_padding_left_right',array(
		'label'	=> __('Slider Content Padding Left Right','vw-education-lite'),
		'description'	=> __('Enter a value in %. Example:20%','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( '50%', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_slidersettings',
		'type'=> 'text',
		'active_callback' => 'vw_education_lite_default_slider'
	));

    //Slider excerpt
	$wp_customize->add_setting( 'vw_education_lite_slider_excerpt_number', array(
		'default'              => 30,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_education_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_education_lite_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','vw-education-lite' ),
		'section'     => 'vw_education_lite_slidersettings',
		'type'        => 'range',
		'settings'    => 'vw_education_lite_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),'active_callback' => 'vw_education_lite_default_slider'
	) );
	
	//Slider height
	$wp_customize->add_setting('vw_education_lite_slider_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_slider_height',array(
		'label'	=> __('Slider Height','vw-education-lite'),
		'description'	=> __('Specify the slider height (px).','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( '500px', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_slidersettings',
		'type'=> 'text',
		'active_callback' => 'vw_education_lite_default_slider'
	));

	$wp_customize->add_setting( 'vw_education_lite_slider_speed', array(
		'default'  => 4000,
		'sanitize_callback'	=> 'vw_education_lite_sanitize_float'
	) );
	$wp_customize->add_control( 'vw_education_lite_slider_speed', array(
		'label' => esc_html__('Slider Transition Speed','vw-education-lite'),
		'section' => 'vw_education_lite_slidersettings',
		'type'  => 'number',
		'active_callback' => 'vw_education_lite_default_slider'
	) );

	//Opacity
	$wp_customize->add_setting('vw_education_lite_slider_opacity_color',array(
      'default'              => 0.5,
      'sanitize_callback' => 'vw_education_lite_sanitize_choices'
	));

	$wp_customize->add_control( 'vw_education_lite_slider_opacity_color', array(
		'label'       => esc_html__( 'Slider Image Opacity','vw-education-lite' ),
		'section'     => 'vw_education_lite_slidersettings',
		'type'        => 'select',
		'settings'    => 'vw_education_lite_slider_opacity_color',
		'choices' => array(
	      '0' =>  esc_attr('0','vw-education-lite'),
	      '0.1' =>  esc_attr('0.1','vw-education-lite'),
	      '0.2' =>  esc_attr('0.2','vw-education-lite'),
	      '0.3' =>  esc_attr('0.3','vw-education-lite'),
	      '0.4' =>  esc_attr('0.4','vw-education-lite'),
	      '0.5' =>  esc_attr('0.5','vw-education-lite'),
	      '0.6' =>  esc_attr('0.6','vw-education-lite'),
	      '0.7' =>  esc_attr('0.7','vw-education-lite'),
	      '0.8' =>  esc_attr('0.8','vw-education-lite'),
	      '0.9' =>  esc_attr('0.9','vw-education-lite')
	),'active_callback' => 'vw_education_lite_default_slider'
	));

	$wp_customize->add_setting( 'vw_education_lite_slider_image_overlay',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ));
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_slider_image_overlay',array(
      	'label' => esc_html__( 'Show / Hide Slider Image Overlay','vw-education-lite' ),
      	'section' => 'vw_education_lite_slidersettings',
      	'active_callback' => 'vw_education_lite_default_slider'
    )));

    $wp_customize->add_setting('vw_education_lite_slider_image_overlay_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_education_lite_slider_image_overlay_color', array(
		'label'    => __('Slider Image Overlay Color', 'vw-education-lite'),
		'section'  => 'vw_education_lite_slidersettings',
		'active_callback' => 'vw_education_lite_default_slider'
	)));

	//Our Featured Courses
	$wp_customize->add_section('vw_education_lite_our_courses',array(
		'title'	=> __('Our Featured Courses','vw-education-lite'),
		'description' => __('For more options of the our featured courses section</br> <a class="go-pro-btn" target="blank" href="http://www.vwthemes.com/themes/vw-education-theme/">GET PRO</a>','vw-education-lite'),
		'panel' => 'vw_education_lite_homepage_panel'
	));	

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'vw_education_lite_sec1_title', array( 
		'selector' => '#our-courses h2', 
		'render_callback' => 'vw_education_lite_customize_partial_vw_education_lite_sec1_title',
	));
	
	$wp_customize->add_setting('vw_education_lite_sec1_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('vw_education_lite_sec1_title',array(
		'label'	=> __('Section Title','vw-education-lite'),
		'section'=> 'vw_education_lite_our_courses',
		'setting'=> 'vw_education_lite_sec1_title',
		'type'=> 'text',
		'active_callback' => 'vw_education_lite_default_slider'
	));	
	
	for ( $count = 0; $count <= 2; $count++ ) {

		$wp_customize->add_setting( 'vw_education_lite_courses_settings' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'vw_education_lite_sanitize_dropdown_pages'
		));
		$wp_customize->add_control( 'vw_education_lite_courses_settings' . $count, array(
			'label'    => __( 'Select Courses Page', 'vw-education-lite' ),
			'section'  => 'vw_education_lite_our_courses',
			'type'     => 'dropdown-pages',
			'active_callback' => 'vw_education_lite_default_slider'
		));
	}

	//search form Section
	$wp_customize->add_section('vw_education_lite_our_project', array(
		'title'       => __('Search Vechicle Section', 'vw-education-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-education-lite'),
		'priority'    => null,
		'panel'       => 'vw_education_lite_homepage_panel',
	));

	$wp_customize->add_setting('vw_education_lite_our_project_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_our_project_text',array(
		'description' => __('<p>1. More options for search form section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for search form section.</p>','vw-education-lite'),
		'section'=> 'vw_education_lite_our_project',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_education_lite_our_project_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_our_project_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_education_lite_guide') ." '>More Info</a>",
		'section'=> 'vw_education_lite_our_project',
		'type'=> 'hidden'
	));

	//Our project Section
	$wp_customize->add_section('vw_education_lite_our_project', array(
		'title'       => __('Project Section', 'vw-education-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-education-lite'),
		'priority'    => null,
		'panel'       => 'vw_education_lite_homepage_panel',
	));

	$wp_customize->add_setting('vw_education_lite_our_project_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_our_project_text',array(
		'description' => __('<p>1. More options for our project section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for our project section.</p>','vw-education-lite'),
		'section'=> 'vw_education_lite_our_project',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_education_lite_our_project_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_our_project_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_education_lite_guide') ." '>More Info</a>",
		'section'=> 'vw_education_lite_our_project',
		'type'=> 'hidden'
	));

	//education products Section
	$wp_customize->add_section('vw_education_lite_education_products', array(
		'title'       => __('Product Section', 'vw-education-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-education-lite'),
		'priority'    => null,
		'panel'       => 'vw_education_lite_homepage_panel',
	));

	$wp_customize->add_setting('vw_education_lite_education_products_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_education_products_text',array(
		'description' => __('<p>1. More options for product section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for our product section.</p>','vw-education-lite'),
		'section'=> 'vw_education_lite_education_products',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_education_lite_education_products_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_education_products_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_education_lite_guide') ." '>More Info</a>",
		'section'=> 'vw_education_lite_education_products',
		'type'=> 'hidden'
	));

	//we offer Section
	$wp_customize->add_section('vw_education_lite_we_offer', array(
		'title'       => __('We Offer Section', 'vw-education-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-education-lite'),
		'priority'    => null,
		'panel'       => 'vw_education_lite_homepage_panel',
	));

	$wp_customize->add_setting('vw_education_lite_we_offer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_we_offer_text',array(
		'description' => __('<p>1. More options for we offer section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for our we offer section.</p>','vw-education-lite'),
		'section'=> 'vw_education_lite_we_offer',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_education_lite_we_offer_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_we_offer_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_education_lite_guide') ." '>More Info</a>",
		'section'=> 'vw_education_lite_we_offer',
		'type'=> 'hidden'
	));

	//faculty Section
	$wp_customize->add_section('vw_education_lite_faculty', array(
		'title'       => __('faculty Section', 'vw-education-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-education-lite'),
		'priority'    => null,
		'panel'       => 'vw_education_lite_homepage_panel',
	));

	$wp_customize->add_setting('vw_education_lite_faculty_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_faculty_text',array(
		'description' => __('<p>1. More options for faculty section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for our faculty section.</p>','vw-education-lite'),
		'section'=> 'vw_education_lite_faculty',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_education_lite_faculty_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_faculty_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_education_lite_guide') ." '>More Info</a>",
		'section'=> 'vw_education_lite_faculty',
		'type'=> 'hidden'
	));

	//our records Section
	$wp_customize->add_section('vw_education_lite_our_records', array(
		'title'       => __('Record Section', 'vw-education-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-education-lite'),
		'priority'    => null,
		'panel'       => 'vw_education_lite_homepage_panel',
	));

	$wp_customize->add_setting('vw_education_lite_our_records_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_our_records_text',array(
		'description' => __('<p>1. More options for record section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for our record section.</p>','vw-education-lite'),
		'section'=> 'vw_education_lite_our_records',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_education_lite_our_records_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_our_records_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_education_lite_guide') ." '>More Info</a>",
		'section'=> 'vw_education_lite_our_records',
		'type'=> 'hidden'
	));

	//gallery Section
	$wp_customize->add_section('vw_education_lite_gallery', array(
		'title'       => __('Gallery Section', 'vw-education-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-education-lite'),
		'priority'    => null,
		'panel'       => 'vw_education_lite_homepage_panel',
	));

	$wp_customize->add_setting('vw_education_lite_gallery_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_gallery_text',array(
		'description' => __('<p>1. More options for gallery section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for our gallery section.</p>','vw-education-lite'),
		'section'=> 'vw_education_lite_gallery',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_education_lite_gallery_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_gallery_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_education_lite_guide') ." '>More Info</a>",
		'section'=> 'vw_education_lite_gallery',
		'type'=> 'hidden'
	));

	//choose course Section
	$wp_customize->add_section('vw_education_lite_choose_course', array(
		'title'       => __('Course Section', 'vw-education-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-education-lite'),
		'priority'    => null,
		'panel'       => 'vw_education_lite_homepage_panel',
	));

	$wp_customize->add_setting('vw_education_lite_choose_course_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_choose_course_text',array(
		'description' => __('<p>1. More options for choose course section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for our choose course section.</p>','vw-education-lite'),
		'section'=> 'vw_education_lite_choose_course',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_education_lite_choose_course_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_choose_course_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_education_lite_guide') ." '>More Info</a>",
		'section'=> 'vw_education_lite_choose_course',
		'type'=> 'hidden'
	));

	//Testimonial Section
	$wp_customize->add_section('vw_education_lite_testimonial', array(
		'title'       => __('Testimonial Section', 'vw-education-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-education-lite'),
		'priority'    => null,
		'panel'       => 'vw_education_lite_homepage_panel',
	));

	$wp_customize->add_setting('vw_education_lite_testimonial_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_testimonial_text',array(
		'description' => __('<p>1. More options for testimonial section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for our testimonial section.</p>','vw-education-lite'),
		'section'=> 'vw_education_lite_testimonial',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_education_lite_testimonial_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_testimonial_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_education_lite_guide') ." '>More Info</a>",
		'section'=> 'vw_education_lite_testimonial',
		'type'=> 'hidden'
	));

	//blog Section
	$wp_customize->add_section('vw_education_lite_blog', array(
		'title'       => __('	Blog Section', 'vw-education-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-education-lite'),
		'priority'    => null,
		'panel'       => 'vw_education_lite_homepage_panel',
	));

	$wp_customize->add_setting('vw_education_lite_blog_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_blog_text',array(
		'description' => __('<p>1. More options for blog section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for our blog section.</p>','vw-education-lite'),
		'section'=> 'vw_education_lite_blog',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_education_lite_blog_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_blog_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_education_lite_guide') ." '>More Info</a>",
		'section'=> 'vw_education_lite_blog',
		'type'=> 'hidden'
	));

	//Footer Text
	$wp_customize->add_section('vw_education_lite_footer_section',array(
		'title'	=> __('Footer Text','vw-education-lite'),
		'description' => __('For more options of the our footer section</br> <a class="go-pro-btn" target="blank" href="http://www.vwthemes.com/themes/vw-education-theme/">GET PRO</a>','vw-education-lite'),
		'priority'	=> null,
		'panel' => 'vw_education_lite_homepage_panel'
	));
	
	$wp_customize->add_setting( 'vw_education_lite_footer_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ));
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_footer_hide_show',array(
      'label' => esc_html__( 'Show / Hide Footer','vw-education-lite' ),
      'section' => 'vw_education_lite_footer_section'
    )));

     // font size
	$wp_customize->add_setting('vw_education_lite_button_footer_font_size',array(
		'default'=> 25,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_button_footer_font_size',array(
		'label'	=> __('Footer Heading Font Size','vw-education-lite'),
  		'type'        => 'number',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'vw_education_lite_footer_section',
	));

	$wp_customize->add_setting('vw_education_lite_button_footer_heading_letter_spacing',array(
		'default'=> 1,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_button_footer_heading_letter_spacing',array(
		'label'	=> __('Heading Letter Spacing','vw-education-lite'),
  		'type'        => 'number',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
	),
		'section'=> 'vw_education_lite_footer_section',
	));

	// text trasform
	$wp_customize->add_setting('vw_education_lite_button_footer_text_transform',array(
		'default'=> 'Capitalize',
		'sanitize_callback'	=> 'vw_education_lite_sanitize_choices'
	));
	$wp_customize->add_control('vw_education_lite_button_footer_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Heading Text Transform','vw-education-lite'),
		'choices' => array(
      'Uppercase' => __('Uppercase','vw-education-lite'),
      'Capitalize' => __('Capitalize','vw-education-lite'),
      'Lowercase' => __('Lowercase','vw-education-lite'),
    ),
		'section'=> 'vw_education_lite_footer_section',
	));

	$wp_customize->add_setting('vw_education_lite_footer_heading_weight',array(
        'default' => '',
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_education_lite_sanitize_choices'
	));
	$wp_customize->add_control('vw_education_lite_footer_heading_weight',array(
        'type' => 'select',
        'label' => __('Heading Font Weight','vw-education-lite'),
        'section' => 'vw_education_lite_footer_section',
        'choices' => array(
        	'100' => __('100','vw-education-lite'),
            '200' => __('200','vw-education-lite'),
            '300' => __('300','vw-education-lite'),
            '400' => __('400','vw-education-lite'),
            '500' => __('500','vw-education-lite'),
            '600' => __('600','vw-education-lite'),
            '700' => __('700','vw-education-lite'),
            '800' => __('800','vw-education-lite'),
            '900' => __('900','vw-education-lite'),
        ),
	) );

	$wp_customize->add_setting('vw_education_lite_footer_template',array(
		'default'	=> esc_html('vw_education_lite-footer-one'),
		'sanitize_callback'	=> 'vw_education_lite_sanitize_choices'
	));
	$wp_customize->add_control('vw_education_lite_footer_template',array(
	  'label'	=> esc_html__('Footer style','vw-education-lite'),
	  'section'	=> 'vw_education_lite_footer',
	  'setting'	=> 'vw_education_lite_footer_template',
	  'type' => 'select',
	  'choices' => array(
	      'vw_education_lite-footer-one' => esc_html__('Style 1', 'vw-education-lite'),
	      'vw_education_lite-footer-two' => esc_html__('Style 2', 'vw-education-lite'),
	      'vw_education_lite-footer-three' => esc_html__('Style 3', 'vw-education-lite'),
	      'vw_education_lite-footer-four' => esc_html__('Style 4', 'vw-education-lite'),
	      'vw_education_lite-footer-five' => esc_html__('Style 5', 'vw-education-lite'),
	      )
	));

	$wp_customize->add_setting('vw_education_lite_footer_background_color', array(
		'default'           => '#222222
		',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_education_lite_footer_background_color', array(
		'label'    => __('Footer Background Color', 'vw-education-lite'),
		'section'  => 'vw_education_lite_footer_section',
	)));

	$wp_customize->add_setting('vw_education_lite_footer_background_image',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'vw_education_lite_footer_background_image',array(
        'label' => __('Footer Background Image','vw-education-lite'),
        'section' => 'vw_education_lite_footer_section'
	)));

	$wp_customize->add_setting('vw_education_lite_footer_img_position',array(
	  'default' => 'center center',
	  'transport' => 'refresh',
	  'sanitize_callback' => 'vw_education_lite_sanitize_choices'
	));
	$wp_customize->add_control('vw_education_lite_footer_img_position',array(
		'type' => 'select',
		'label' => __('Footer Image Position','vw-education-lite'),
		'section' => 'vw_education_lite_footer_section',
		'choices' 	=> array(
			'left top' 		=> esc_html__( 'Top Left', 'vw-education-lite' ),
			'center top'   => esc_html__( 'Top', 'vw-education-lite' ),
			'right top'   => esc_html__( 'Top Right', 'vw-education-lite' ),
			'left center'   => esc_html__( 'Left', 'vw-education-lite' ),
			'center center'   => esc_html__( 'Center', 'vw-education-lite' ),
			'right center'   => esc_html__( 'Right', 'vw-education-lite' ),
			'left bottom'   => esc_html__( 'Bottom Left', 'vw-education-lite' ),
			'center bottom'   => esc_html__( 'Bottom', 'vw-education-lite' ),
			'right bottom'   => esc_html__( 'Bottom Right', 'vw-education-lite' ),
		), 
	));

	// Footer
	$wp_customize->add_setting('vw_education_lite_img_footer',array(
		'default'=> 'scroll',
		'sanitize_callback'	=> 'vw_education_lite_sanitize_choices'
	));
	$wp_customize->add_control('vw_education_lite_img_footer',array(
		'type' => 'select',
		'label'	=> __('Footer Background Attatchment','vw-education-lite'),
		'choices' => array(
            'fixed' => __('fixed','vw-education-lite'),
            'scroll' => __('scroll','vw-education-lite'),
        ),
		'section'=> 'vw_education_lite_footer_section',
	));

	// footer padding
	$wp_customize->add_setting('vw_education_lite_footer_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_footer_padding',array(
		'label'	=> __('Footer Top Bottom Padding','vw-education-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-education-lite'),
		'input_attrs' => array(
      'placeholder' => __( '10px', 'vw-education-lite' ),
    ),
		'section'=> 'vw_education_lite_footer_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_education_lite_footer_widgets_heading',array(
        'default' => 'Left',
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_education_lite_sanitize_choices'
	));
	$wp_customize->add_control('vw_education_lite_footer_widgets_heading',array(
        'type' => 'select',
        'label' => __('Footer Widget Heading','vw-education-lite'),
        'section' => 'vw_education_lite_footer_section',
        'choices' => array(
        	'Left' => __('Left','vw-education-lite'),
            'Center' => __('Center','vw-education-lite'),
            'Right' => __('Right','vw-education-lite')
        ),
	) );

	$wp_customize->add_setting('vw_education_lite_footer_widgets_content',array(
        'default' => 'Left',
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_education_lite_sanitize_choices'
	));
	$wp_customize->add_control('vw_education_lite_footer_widgets_content',array(
        'type' => 'select',
        'label' => __('Footer Widget Content','vw-education-lite'),
        'section' => 'vw_education_lite_footer_section',
        'choices' => array(
        	'Left' => __('Left','vw-education-lite'),
            'Center' => __('Center','vw-education-lite'),
            'Right' => __('Right','vw-education-lite')
        ),
	) );

	// footer social icon
  	$wp_customize->add_setting( 'vw_education_lite_footer_icon',array(
		'default' => false,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ) );
  	$wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_footer_icon',array(
		'label' => esc_html__( 'Show / Hide Footer Social Icon','vw-education-lite' ),
		'section' => 'vw_education_lite_footer_section'
    )));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_education_lite_footer_copy', array( 
		'selector' => '.copyright-wrapper .copyright p', 
		'render_callback' => 'vw_education_lite_customize_partial_vw_education_lite_footer_copy', 
	));
	
	$wp_customize->add_setting( 'vw_education_lite_copyright_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ));
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_copyright_hide_show',array(
      'label' => esc_html__( 'Show / Hide Copyright','vw-education-lite' ),
      'section' => 'vw_education_lite_footer_section'
    )));

	$wp_customize->add_setting('vw_education_lite_copyright_background_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_education_lite_copyright_background_color', array(
		'label'    => __('Copyright Background Color', 'vw-education-lite'),
		'section'  => 'vw_education_lite_footer_section',
	)));

	$wp_customize->add_setting('vw_education_lite_footer_copy',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field',
	));
	
	$wp_customize->add_control('vw_education_lite_footer_copy',array(
		'label'	=> __('Copyright Text','vw-education-lite'),
		'section'	=> 'vw_education_lite_footer_section',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('vw_education_lite_copyright_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_copyright_font_size',array(
		'label'	=> __('Copyright Font Size','vw-education-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_footer_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_education_lite_copyright_alingment',array(
        'default' => 'center',
        'sanitize_callback' => 'vw_education_lite_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Education_Lite_Image_Radio_Control($wp_customize, 'vw_education_lite_copyright_alingment', array(
        'type' => 'select',
        'label' => __('Copyright Alignment','vw-education-lite'),
        'section' => 'vw_education_lite_footer_section',
        'settings' => 'vw_education_lite_copyright_alingment',
        'choices' => array(
            'left' => esc_url(get_template_directory_uri()).'/images/copyright1.png',
            'center' => esc_url(get_template_directory_uri()).'/images/copyright2.png',
            'right' => esc_url(get_template_directory_uri()).'/images/copyright3.png'
    ))));

    $wp_customize->add_setting('vw_education_lite_copyright_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_copyright_padding_top_bottom',array(
		'label'	=> __('Copyright Padding Top Bottom','vw-education-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_footer_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_education_lite_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','vw-education-lite' ),
      	'section' => 'vw_education_lite_footer_section'
    )));

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_education_lite_scroll_top_icon', array( 
		'selector' => '.scrollup i', 
		'render_callback' => 'vw_education_lite_customize_partial_vw_education_lite_scroll_top_icon', 
	));

    $wp_customize->add_setting('vw_education_lite_scroll_top_icon',array(
		'default'	=> 'fas fa-angle-up',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Education_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_education_lite_scroll_top_icon',array(
		'label'	=> __('Add Scroll to Top Icon','vw-education-lite'),
		'transport' => 'refresh',
		'section'	=> 'vw_education_lite_footer_section',
		'setting'	=> 'vw_education_lite_scroll_top_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_education_lite_scroll_to_top_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_scroll_to_top_font_size',array(
		'label'	=> __('Icon Font Size','vw-education-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_footer_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_education_lite_scroll_to_top_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_scroll_to_top_padding_top_bottom',array(
		'label'	=> __('Icon Padding Top Bottom','vw-education-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_footer_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_education_lite_scroll_to_top_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_scroll_to_top_width',array(
		'label'	=> __('Icon Width','vw-education-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_footer_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_education_lite_scroll_to_top_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_scroll_to_top_height',array(
		'label'	=> __('Icon Height','vw-education-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_footer_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_education_lite_scroll_to_top_border_radius', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_education_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_education_lite_scroll_to_top_border_radius', array(
		'label'       => esc_html__( 'Icon Border Radius','vw-education-lite' ),
		'section'     => 'vw_education_lite_footer_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('vw_education_lite_scroll_top_alignment',array(
        'default' => 'Right',
        'sanitize_callback' => 'vw_education_lite_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Education_Lite_Image_Radio_Control($wp_customize, 'vw_education_lite_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','vw-education-lite'),
        'section' => 'vw_education_lite_footer_section',
        'settings' => 'vw_education_lite_scroll_top_alignment',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/images/layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/images/layout2.png',
            'Right' => esc_url(get_template_directory_uri()).'/images/layout3.png'
    ))));

		//Blog Post
	$wp_customize->add_panel( $VWEducationLiteParentPanel );

	$BlogPostParentPanel = new VW_Education_Lite_WP_Customize_Panel( $wp_customize, 'blog_post_parent_panel', array(
		'title' => __( 'Blog Post Settings', 'vw-education-lite' ),
		'panel' => 'vw_education_lite_panel_id',
	));

	$wp_customize->add_panel( $BlogPostParentPanel );

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'vw_education_lite_post_settings', array(
		'title' => __( 'Post Settings', 'vw-education-lite' ),
		'panel' => 'blog_post_parent_panel',
	));

	//Blog layout
	$wp_customize->add_setting('vw_education_lite_blog_layout_option',array(
        'default' => 'Default',
        'sanitize_callback' => 'vw_education_lite_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Education_Lite_Image_Radio_Control($wp_customize, 'vw_education_lite_blog_layout_option', array(
        'type' => 'select',
        'label' => __('Blog Layouts','vw-education-lite'),
        'section' => 'vw_education_lite_post_settings',
        'choices' => array(
            'Default' => esc_url(get_template_directory_uri()).'/images/blog-layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/images/blog-layout2.png',
            'Left' => esc_url(get_template_directory_uri()).'/images/blog-layout3.png',
    ))));

   	// Add Settings and Controls for Layout
	$wp_customize->add_setting('vw_education_lite_theme_options',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'vw_education_lite_sanitize_choices'	        
	) );
	$wp_customize->add_control('vw_education_lite_theme_options', array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','vw-education-lite'),
        'description' => __('Here you can change the sidebar layout for posts. ','vw-education-lite'),
        'section' => 'vw_education_lite_post_settings',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-education-lite'),
            'Right Sidebar' => __('Right Sidebar','vw-education-lite'),
            'One Column' => __('One Column','vw-education-lite'),
            'Three Columns' => __('Three Columns','vw-education-lite'),
            'Four Columns' => __('Four Columns','vw-education-lite'),
            'Grid Layout' => __('Grid Layout','vw-education-lite')
        ),
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_education_lite_toggle_postdate', array( 
		'selector' => '.services-box h2 a', 
		'render_callback' => 'vw_education_lite_customize_partial_vw_education_lite_toggle_postdate', 
	));

  	$wp_customize->add_setting('vw_education_lite_toggle_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Education_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_education_lite_toggle_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','vw-education-lite'),
		'transport' => 'refresh',
		'section'	=> 'vw_education_lite_post_settings',
		'setting'	=> 'vw_education_lite_toggle_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'vw_education_lite_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_toggle_postdate',array(
        'label' => esc_html__( 'Show / Hide Post Date','vw-education-lite' ),
        'section' => 'vw_education_lite_post_settings'
    )));

    $wp_customize->add_setting('vw_education_lite_toggle_author_icon',array(
		'default'	=> 'far fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Education_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_education_lite_toggle_author_icon',array(
		'label'	=> __('Add Author Icon','vw-education-lite'),
		'transport' => 'refresh',
		'section'	=> 'vw_education_lite_post_settings',
		'setting'	=> 'vw_education_lite_toggle_author_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'vw_education_lite_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_toggle_author',array(
		'label' => esc_html__( 'Show / Hide Author','vw-education-lite' ),
		'section' => 'vw_education_lite_post_settings'
    )));

    $wp_customize->add_setting('vw_education_lite_toggle_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Education_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_education_lite_toggle_comments_icon',array(
		'label'	=> __('Add Comments Icon','vw-education-lite'),
		'transport' => 'refresh',
		'section'	=> 'vw_education_lite_post_settings',
		'setting'	=> 'vw_education_lite_toggle_comments_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'vw_education_lite_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_toggle_comments',array(
		'label' => esc_html__( 'Show / Hide Comments','vw-education-lite' ),
		'section' => 'vw_education_lite_post_settings'
    )));

    $wp_customize->add_setting('vw_education_lite_toggle_time_icon',array(
		'default'	=> 'fas fa-clock',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Education_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_education_lite_toggle_time_icon',array(
		'label'	=> __('Add Time Icon','vw-education-lite'),
		'transport' => 'refresh',
		'section'	=> 'vw_education_lite_post_settings',
		'setting'	=> 'vw_education_lite_toggle_time_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'vw_education_lite_toggle_time',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_toggle_time',array(
		'label' => esc_html__( 'Show / Hide Time','vw-education-lite' ),
		'section' => 'vw_education_lite_post_settings'
    )));

    $wp_customize->add_setting( 'vw_education_lite_featured_image_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_education_lite_switch_sanitization'
	));
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_featured_image_hide_show', array(
		'label' => esc_html__( 'Show / Hide Featured Image','vw-education-lite' ),
		'section' => 'vw_education_lite_post_settings'
    )));

    $wp_customize->add_setting( 'vw_education_lite_featured_image_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_education_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_education_lite_featured_image_border_radius', array(
		'label'       => esc_html__( 'Featured Image Border Radius','vw-education-lite' ),
		'section'     => 'vw_education_lite_post_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'vw_education_lite_featured_image_box_shadow', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_education_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_education_lite_featured_image_box_shadow', array(
		'label'       => esc_html__( 'Featured Image Box Shadow','vw-education-lite' ),
		'section'     => 'vw_education_lite_post_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Featured Image
	$wp_customize->add_setting('vw_education_lite_blog_post_featured_image_dimension',array(
	       'default' => 'default',
	       'sanitize_callback'	=> 'vw_education_lite_sanitize_choices'
	));
  	$wp_customize->add_control('vw_education_lite_blog_post_featured_image_dimension',array(
     'type' => 'select',
     'label'	=> __('Blog Post Featured Image Dimension','vw-education-lite'),
     'section'	=> 'vw_education_lite_post_settings',
     'choices' => array(
          'default' => __('Default','vw-education-lite'),
          'custom' => __('Custom Image Size','vw-education-lite'),
      ),
  	));

	$wp_customize->add_setting('vw_education_lite_blog_post_featured_image_custom_width',array(
			'default'=> '',
			'sanitize_callback'	=> 'sanitize_text_field'
		));
	$wp_customize->add_control('vw_education_lite_blog_post_featured_image_custom_width',array(
			'label'	=> __('Featured Image Custom Width','vw-education-lite'),
			'description'	=> __('Enter a value in pixels. Example:20px','vw-education-lite'),
			'input_attrs' => array(
	    'placeholder' => __( '10px', 'vw-education-lite' ),),
			'section'=> 'vw_education_lite_post_settings',
			'type'=> 'text',
			'active_callback' => 'vw_education_lite_blog_post_featured_image_dimension'
		));

	$wp_customize->add_setting('vw_education_lite_blog_post_featured_image_custom_height',array(
			'default'=> '',
			'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_blog_post_featured_image_custom_height',array(
			'label'	=> __('Featured Image Custom Height','vw-education-lite'),
			'description'	=> __('Enter a value in pixels. Example:20px','vw-education-lite'),
			'input_attrs' => array(
	    'placeholder' => __( '10px', 'vw-education-lite' ),),
			'section'=> 'vw_education_lite_post_settings',
			'type'=> 'text',
			'active_callback' => 'vw_education_lite_blog_post_featured_image_dimension'
	));

    $wp_customize->add_setting( 'vw_education_lite_excerpt_number', array(
		'default'              => 30,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_education_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_education_lite_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','vw-education-lite' ),
		'section'     => 'vw_education_lite_post_settings',
		'type'        => 'range',
		'settings'    => 'vw_education_lite_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('vw_education_lite_meta_field_separator',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','vw-education-lite'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','vw-education-lite'),
		'section'=> 'vw_education_lite_post_settings',
		'type'=> 'text'
	));

    $wp_customize->add_setting('vw_education_lite_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_education_lite_sanitize_choices'
	));
	$wp_customize->add_control('vw_education_lite_excerpt_settings',array(
        'type' => 'select',
        'label' => __('Post Content','vw-education-lite'),
        'section' => 'vw_education_lite_post_settings',
        'choices' => array(
        	'Content' => __('Content','vw-education-lite'),
            'Excerpt' => __('Excerpt','vw-education-lite'),
            'No Content' => __('No Content','vw-education-lite')
        ),
	) );

	$wp_customize->add_setting('vw_education_lite_excerpt_suffix',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_excerpt_suffix',array(
		'label'	=> __('Add Excerpt Suffix','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( '[...]', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_post_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_education_lite_blog_pagination_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_blog_pagination_hide_show',array(
      'label' => esc_html__( 'Show / Hide Blog Pagination','vw-education-lite' ),
      'section' => 'vw_education_lite_post_settings'
    )));

	$wp_customize->add_setting( 'vw_education_lite_blog_pagination_type', array(
        'default'			=> 'blog-page-numbers',
        'sanitize_callback'	=> 'vw_education_lite_sanitize_choices'
    ));
    $wp_customize->add_control( 'vw_education_lite_blog_pagination_type', array(
        'section' => 'vw_education_lite_post_settings',
        'type' => 'select',
        'label' => __( 'Blog Pagination', 'vw-education-lite' ),
        'choices'		=> array(
            'blog-page-numbers'  => __( 'Numeric', 'vw-education-lite' ),
            'next-prev' => __( 'Older Posts/Newer Posts', 'vw-education-lite' ),
    )));

    $wp_customize->add_setting('vw_education_lite_blog_page_posts_settings',array(
        'default' => 'Into Blocks',
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_education_lite_sanitize_choices'
	));
	$wp_customize->add_control('vw_education_lite_blog_page_posts_settings',array(
        'type' => 'select',
        'label' => __('Display Blog Posts','vw-education-lite'),
        'section' => 'vw_education_lite_post_settings',
        'choices' => array(
        	'Into Blocks' => __('Into Blocks','vw-education-lite'),
            'Without Blocks' => __('Without Blocks','vw-education-lite')
        ),
	) );

    // Button Settings
	$wp_customize->add_section( 'vw_education_lite_button_settings', array(
		'title' => __( 'Button Settings', 'vw-education-lite' ),
		'panel' => 'blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_education_lite_button_text', array( 
		'selector' => '.services-box .read-btn a', 
		'render_callback' => 'vw_education_lite_customize_partial_vw_education_lite_button_text', 
	));

    $wp_customize->add_setting('vw_education_lite_button_text',array(
		'default'=> esc_html__( 'Read More', 'vw-education-lite' ),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_button_text',array(
		'label'	=> __('Add Blog Button Text','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Read More', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_button_settings',
		'type'=> 'text'
	));

	// font size button
	$wp_customize->add_setting('vw_education_lite_button_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_button_font_size',array(
		'label'	=> __('Button Font Size','vw-education-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-education-lite'),
		'input_attrs' => array(
     	'placeholder' => __( '10px', 'vw-education-lite' ),
    ),
    	'type'        => 'text',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'vw_education_lite_button_settings',
	));

	$wp_customize->add_setting( 'vw_education_lite_button_border_radius', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_education_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_education_lite_button_border_radius', array(
		'label'       => esc_html__( 'Button Border Radius','vw-education-lite' ),
		'section'     => 'vw_education_lite_button_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('vw_education_lite_button_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_button_padding_top_bottom',array(
		'label'	=> __('Padding Top Bottom','vw-education-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_education_lite_button_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_button_padding_left_right',array(
		'label'	=> __('Padding Left Right','vw-education-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_education_lite_button_letter_spacing',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_button_letter_spacing',array(
		'label'	=> __('Button Letter Spacing','vw-education-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-education-lite'),
		'input_attrs' => array(
      	'placeholder' => __( '10px', 'vw-education-lite' ),
    ),
    	'type'        => 'text',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'vw_education_lite_button_settings',
	));

	// text trasform
	$wp_customize->add_setting('vw_education_lite_button_text_transform',array(
		'default'=> 'Uppercase',
		'sanitize_callback'	=> 'vw_education_lite_sanitize_choices'
	));
	$wp_customize->add_control('vw_education_lite_button_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Button Text Transform','vw-education-lite'),
		'choices' => array(
            'Uppercase' => __('Uppercase','vw-education-lite'),
            'Capitalize' => __('Capitalize','vw-education-lite'),
            'Lowercase' => __('Lowercase','vw-education-lite'),
        ),
		'section'=> 'vw_education_lite_button_settings',
	));

	// Related Post Settings
	$wp_customize->add_section( 'vw_education_lite_related_posts_settings', array(
		'title' => __( 'Related Posts Settings', 'vw-education-lite' ),
		'panel' => 'blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_education_lite_related_post_title', array( 
		'selector' => '.related-post h3', 
		'render_callback' => 'vw_education_lite_customize_partial_vw_education_lite_related_post_title', 
	));

    $wp_customize->add_setting( 'vw_education_lite_related_post',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_related_post',array(
		'label' => esc_html__( 'Show / Hide Related Post','vw-education-lite' ),
		'section' => 'vw_education_lite_related_posts_settings'
    )));

    $wp_customize->add_setting('vw_education_lite_related_post_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_related_post_title',array(
		'label'	=> __('Add Related Post Title','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Related Post', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_related_posts_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('vw_education_lite_related_posts_count',array(
		'default'=> 3,
		'sanitize_callback'	=> 'vw_education_lite_sanitize_float'
	));
	$wp_customize->add_control('vw_education_lite_related_posts_count',array(
		'label'	=> __('Add Related Post Count','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( '3', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_related_posts_settings',
		'type'=> 'number'
	));

	$wp_customize->add_setting( 'vw_education_lite_related_posts_excerpt_number', array(
		'default'              => 20,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_education_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_education_lite_related_posts_excerpt_number', array(
		'label'       => esc_html__( 'Related Posts Excerpt length','vw-education-lite' ),
		'section'     => 'vw_education_lite_related_posts_settings',
		'type'        => 'range',
		'settings'    => 'vw_education_lite_related_posts_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'vw_education_lite_related_posts_excerpt_number', array(
		'default'              => 20,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_education_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_education_lite_related_posts_excerpt_number', array(
		'label'       => esc_html__( 'Related Posts Excerpt length','vw-education-lite' ),
		'section'     => 'vw_education_lite_related_posts_settings',
		'type'        => 'range',
		'settings'    => 'vw_education_lite_related_posts_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	// Single Posts Settings
	$wp_customize->add_section( 'vw_education_lite_single_blog_settings', array(
		'title' => __( 'Single Post Settings', 'vw-education-lite' ),
		'panel' => 'blog_post_parent_panel',
	));

  	$wp_customize->add_setting('vw_education_lite_single_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Education_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_education_lite_single_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','vw-education-lite'),
		'transport' => 'refresh',
		'section'	=> 'vw_education_lite_single_blog_settings',
		'setting'	=> 'vw_education_lite_single_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'vw_education_lite_single_postdate',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'vw_education_lite_switch_sanitization'
	) );
	$wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_single_postdate',array(
	    'label' => esc_html__( 'Show / Hide Date','vw-education-lite' ),
	   'section' => 'vw_education_lite_single_blog_settings'
	)));

	$wp_customize->add_setting('vw_education_lite_single_author_icon',array(
		'default'	=> 'far fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Education_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_education_lite_single_author_icon',array(
		'label'	=> __('Add Author Icon','vw-education-lite'),
		'transport' => 'refresh',
		'section'	=> 'vw_education_lite_single_blog_settings',
		'setting'	=> 'vw_education_lite_single_author_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'vw_education_lite_single_author',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'vw_education_lite_switch_sanitization'
	) );
	$wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_single_author',array(
	    'label' => esc_html__( 'Show / Hide Author','vw-education-lite' ),
	    'section' => 'vw_education_lite_single_blog_settings'
	)));

   	$wp_customize->add_setting('vw_education_lite_single_comments_icon',array(
		'default'	=> 'fas fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Education_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_education_lite_single_comments_icon',array(
		'label'	=> __('Add Comments Icon','vw-education-lite'),
		'transport' => 'refresh',
		'section'	=> 'vw_education_lite_single_blog_settings',
		'setting'	=> 'vw_education_lite_single_comments_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'vw_education_lite_single_comments',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'vw_education_lite_switch_sanitization'
	) );
	$wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_single_comments',array(
	    'label' => esc_html__( 'Show / Hide Comments','vw-education-lite' ),
	    'section' => 'vw_education_lite_single_blog_settings'
	)));

  	$wp_customize->add_setting('vw_education_lite_single_time_icon',array(
		'default'	=> 'fas fa-clock',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Education_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_education_lite_single_time_icon',array(
		'label'	=> __('Add Time Icon','vw-education-lite'),
		'transport' => 'refresh',
		'section'	=> 'vw_education_lite_single_blog_settings',
		'setting'	=> 'vw_education_lite_single_time_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'vw_education_lite_single_time',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'vw_education_lite_switch_sanitization'
	) );
	$wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_single_time',array(
	    'label' => esc_html__( 'Show / Hide Time','vw-education-lite' ),
	    'section' => 'vw_education_lite_single_blog_settings'
	)));

	$wp_customize->add_setting( 'vw_education_lite_single_post_breadcrumb',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_single_post_breadcrumb',array(
		'label' => esc_html__( 'Show / Hide Breadcrumb','vw-education-lite' ),
		'section' => 'vw_education_lite_single_blog_settings'
    )));

    // Single Posts Category
  	$wp_customize->add_setting( 'vw_education_lite_single_post_category',array(
		'default' => true,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ) );
  	$wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_single_post_category',array(
		'label' => esc_html__( 'Show / Hide Category','vw-education-lite' ),
		'section' => 'vw_education_lite_single_blog_settings'
    )));

	$wp_customize->add_setting( 'vw_education_lite_toggle_tags',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_education_lite_switch_sanitization'
	));
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_toggle_tags', array(
		'label' => esc_html__( 'Show / Hide Tags','vw-education-lite' ),
		'section' => 'vw_education_lite_single_blog_settings'
    )));

    $wp_customize->add_setting('vw_education_lite_single_post_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_single_post_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','vw-education-lite'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','vw-education-lite'),
		'section'=> 'vw_education_lite_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_education_lite_single_blog_post_navigation_show_hide',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_education_lite_switch_sanitization'
	));
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_single_blog_post_navigation_show_hide', array(
		'label' => esc_html__( 'Show / Hide Post Navigation','vw-education-lite' ),
		'section' => 'vw_education_lite_single_blog_settings'
    )));

	//navigation text
	$wp_customize->add_setting('vw_education_lite_single_blog_prev_navigation_text',array(
		'default'=> 'PREVIOUS PAGE',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_single_blog_prev_navigation_text',array(
		'label'	=> __('Post Navigation Text','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'PREVIOUS PAGE', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_education_lite_single_blog_next_navigation_text',array(
		'default'=> 'NEXT PAGE',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_single_blog_next_navigation_text',array(
		'label'	=> __('Post Navigation Text','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'NEXT PAGE', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_education_lite_single_blog_comment_title',array(
		'default'=> 'Leave a Reply',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_education_lite_single_blog_comment_title',array(
		'label'	=> __('Add Comment Title','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Leave a Reply', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_education_lite_single_blog_comment_button_text',array(
		'default'=> 'Post Comment',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_education_lite_single_blog_comment_button_text',array(
		'label'	=> __('Add Comment Button Text','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Post Comment', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_single_blog_settings',
		'type'=> 'text'
	));

	// Grid layout setting
	$wp_customize->add_section( 'vw_education_lite_grid_layout_settings', array(
		'title' => __( 'Grid Layout Settings', 'vw-education-lite' ),
		'panel' => 'blog_post_parent_panel',
	));

  	$wp_customize->add_setting('vw_education_lite_grid_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Education_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_education_lite_grid_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','vw-education-lite'),
		'transport' => 'refresh',
		'section'	=> 'vw_education_lite_grid_layout_settings',
		'setting'	=> 'vw_education_lite_grid_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'vw_education_lite_grid_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_grid_postdate',array(
        'label' => esc_html__( 'Show / Hide Post Date','vw-education-lite' ),
        'section' => 'vw_education_lite_grid_layout_settings'
    )));

	$wp_customize->add_setting('vw_education_lite_grid_author_icon',array(
		'default'	=> 'far fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Education_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_education_lite_grid_author_icon',array(
		'label'	=> __('Add Author Icon','vw-education-lite'),
		'transport' => 'refresh',
		'section'	=> 'vw_education_lite_grid_layout_settings',
		'setting'	=> 'vw_education_lite_grid_author_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'vw_education_lite_grid_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_grid_author',array(
		'label' => esc_html__( 'Show / Hide Author','vw-education-lite' ),
		'section' => 'vw_education_lite_grid_layout_settings'
    )));

   	$wp_customize->add_setting('vw_education_lite_grid_comments_icon',array(
		'default'	=> 'fas fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Education_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_education_lite_grid_comments_icon',array(
		'label'	=> __('Add Comments Icon','vw-education-lite'),
		'transport' => 'refresh',
		'section'	=> 'vw_education_lite_grid_layout_settings',
		'setting'	=> 'vw_education_lite_grid_comments_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'vw_education_lite_grid_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_grid_comments',array(
		'label' => esc_html__( 'Show / Hide Comments','vw-education-lite' ),
		'section' => 'vw_education_lite_grid_layout_settings'
    )));

 	$wp_customize->add_setting('vw_education_lite_grid_post_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_grid_post_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','vw-education-lite'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','vw-education-lite'),
		'section'=> 'vw_education_lite_grid_layout_settings',
		'type'=> 'text'
	)); 

  	$wp_customize->add_setting('vw_education_lite_display_grid_posts_settings',array(
	    'default' => 'Into Blocks',
	    'transport' => 'refresh',
	    'sanitize_callback' => 'vw_education_lite_sanitize_choices'
	));
	$wp_customize->add_control('vw_education_lite_display_grid_posts_settings',array(
	    'type' => 'select',
	    'label' => __('Display Grid Posts','vw-education-lite'),
	    'section' => 'vw_education_lite_grid_layout_settings',
	    'choices' => array(
	    	'Into Blocks' => __('Into Blocks','vw-education-lite'),
	      'Without Blocks' => __('Without Blocks','vw-education-lite')
	      ),
	) );

	$wp_customize->add_setting('vw_education_lite_grid_button_text',array(
		'default'=> esc_html__('Read More','vw-education-lite'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_grid_button_text',array(
		'label'	=> esc_html__('Add Button Text','vw-education-lite'),
		'input_attrs' => array(
        'placeholder' => esc_html__( 'Read More', 'vw-education-lite' ),
      ),
		'section'=> 'vw_education_lite_grid_layout_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_education_lite_grid_excerpt_suffix',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_grid_excerpt_suffix',array(
		'label'	=> __('Add Excerpt Suffix','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( '[...]', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_grid_layout_settings',
		'type'=> 'text'
	));

  	//Others Settings
  	$OtherParentPanel = new VW_Education_Lite_WP_Customize_Panel( $wp_customize, 'vw_education_lite_others_panel', array(
		'title' => __( 'Others Settings', 'vw-education-lite' ),
		'panel' => 'vw_education_lite_panel_id',
	));

	$wp_customize->add_panel( $OtherParentPanel );

	//Layouts
	$wp_customize->add_section( 'vw_education_lite_left_right', array(
    	'title'      => esc_html__( 'General Settings', 'vw-education-lite' ),
		'priority'   => null,
		'panel' => 'vw_education_lite_others_panel'
	) );

	$wp_customize->add_setting('vw_education_lite_width_option',array(
        'default' => 'Full Width',
        'sanitize_callback' => 'vw_education_lite_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Education_Lite_Image_Radio_Control($wp_customize, 'vw_education_lite_width_option', array(
        'type' => 'select',
        'label' => __('Width Layouts','vw-education-lite'),
        'description' => __('Here you can change the width layout of Website.','vw-education-lite'),
        'section' => 'vw_education_lite_left_right',
        'choices' => array(
            'Full Width' => esc_url(get_template_directory_uri()).'/images/full-width.png',
            'Wide Width' => esc_url(get_template_directory_uri()).'/images/wide-width.png',
            'Boxed' => esc_url(get_template_directory_uri()).'/images/boxed-width.png',
    ))));

	$wp_customize->add_setting('vw_education_lite_page_layout',array(
        'default' => 'One Column',
        'sanitize_callback' => 'vw_education_lite_sanitize_choices'
	));
	$wp_customize->add_control('vw_education_lite_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','vw-education-lite'),
        'description' => __('Here you can change the sidebar layout for pages. ','vw-education-lite'),
        'section' => 'vw_education_lite_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-education-lite'),
            'Right Sidebar' => __('Right Sidebar','vw-education-lite'),
            'One Column' => __('One Column','vw-education-lite')
        ),
	) );

	$wp_customize->add_setting( 'vw_education_lite_single_page_breadcrumb',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_single_page_breadcrumb',array(
		'label' => esc_html__( 'Show / Hide Page Breadcrumb','vw-education-lite' ),
		'section' => 'vw_education_lite_left_right'
    )));

	//Wow Animation
	$wp_customize->add_setting( 'vw_education_lite_animation',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ));
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_animation',array(
        'label' => esc_html__( 'Show / Hide Animations','vw-education-lite' ),
        'description' => __('Here you can disable overall site animation effect','vw-education-lite'),
        'section' => 'vw_education_lite_left_right'
    )));

	//Pre-Loader
	$wp_customize->add_setting( 'vw_education_lite_loader_enable',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_loader_enable',array(
        'label' => esc_html__( 'Show / Hide Pre-Loader','vw-education-lite' ),
        'section' => 'vw_education_lite_left_right'
    )));

	$wp_customize->add_setting('vw_education_lite_preloader_bg_color', array(
		'default'           => '#99ce34',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_education_lite_preloader_bg_color', array(
		'label'    => __('Pre-Loader Background Color', 'vw-education-lite'),
		'section'  => 'vw_education_lite_left_right',
	)));

	$wp_customize->add_setting('vw_education_lite_preloader_border_color', array(
		'default'           => '#ffffff',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_education_lite_preloader_border_color', array(
		'label'    => __('Pre-Loader Border Color', 'vw-education-lite'),
		'section'  => 'vw_education_lite_left_right',
	)));

	$wp_customize->add_setting('vw_education_lite_preloader_bg_img',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'vw_education_lite_preloader_bg_img',array(
        'label' => __('Preloader Background Image','vw-education-lite'),
        'section' => 'vw_education_lite_left_right'
	)));

	//404 Page Setting
	$wp_customize->add_section('vw_education_lite_404_page',array(
		'title'	=> __('404 Page Settings','vw-education-lite'),
		'panel' => 'vw_education_lite_others_panel',
	));	

	$wp_customize->add_setting('vw_education_lite_404_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_education_lite_404_page_title',array(
		'label'	=> __('Add Title','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( '404 Not Found', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_education_lite_404_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_education_lite_404_page_content',array(
		'label'	=> __('Add Text','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Looks like you have taken a wrong turn, Dont worry, it happens to the best of us.', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_education_lite_404_page_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_404_page_button_text',array(
		'label'	=> __('Add Button Text','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Back to Home Page', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_404_page',
		'type'=> 'text'
	));

	//No Result Page Setting
	$wp_customize->add_section('vw_education_lite_no_results_page',array(
		'title'	=> __('No Results Page Settings','vw-education-lite'),
		'panel' => 'vw_education_lite_others_panel',
	));	

	$wp_customize->add_setting('vw_education_lite_no_results_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_education_lite_no_results_page_title',array(
		'label'	=> __('Add Title','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Nothing Found', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_no_results_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_education_lite_no_results_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_education_lite_no_results_page_content',array(
		'label'	=> __('Add Text','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Sorry, but nothing matched your search terms. Please try again with some different keywords.', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_no_results_page',
		'type'=> 'text'
	));

	//Responsive Media Settings
	$wp_customize->add_section('vw_education_lite_responsive_media',array(
		'title'	=> __('Responsive Media','vw-education-lite'),
		'panel' => 'vw_education_lite_others_panel',
	));

	$wp_customize->add_setting( 'vw_education_lite_resp_topbar_hide_show',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_resp_topbar_hide_show',array(
		'label' => esc_html__( 'Show / Hide Topbar','vw-education-lite' ),
		'section' => 'vw_education_lite_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_education_lite_stickyheader_hide_show',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ));
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_stickyheader_hide_show',array(
      'label' => esc_html__( 'Show / Hidev Sticky Header','vw-education-lite' ),
      'section' => 'vw_education_lite_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_education_lite_resp_slider_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_resp_slider_hide_show',array(
      'label' => esc_html__( 'Show / Hide Slider','vw-education-lite' ),
      'section' => 'vw_education_lite_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_education_lite_sidebar_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_sidebar_hide_show',array(
      'label' => esc_html__( 'Show / Hide Sidebar','vw-education-lite' ),
      'section' => 'vw_education_lite_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_education_lite_resp_scroll_top_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_resp_scroll_top_hide_show',array(
      'label' => esc_html__( 'Show / Hide Scroll To Top','vw-education-lite' ),
      'section' => 'vw_education_lite_responsive_media'
    )));

    $wp_customize->add_setting('vw_education_lite_res_menu_open_icon',array(
		'default'	=> 'fas fa-bars',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Education_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_education_lite_res_menu_open_icon',array(
		'label'	=> __('Add Open Menu Icon','vw-education-lite'),
		'transport' => 'refresh',
		'section'	=> 'vw_education_lite_responsive_media',
		'setting'	=> 'vw_education_lite_res_menu_open_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_education_lite_res_close_menu_icon',array(
		'default'	=> 'fas fa-times',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Education_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_education_lite_res_close_menu_icon',array(
		'label'	=> __('Add Close Menu Icon','vw-education-lite'),
		'transport' => 'refresh',
		'section'	=> 'vw_education_lite_responsive_media',
		'setting'	=> 'vw_education_lite_res_close_menu_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_education_lite_resp_menu_toggle_btn_bg_color', array(
		'default'           => '#222222',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_education_lite_resp_menu_toggle_btn_bg_color', array(
		'label'    => __('Toggle Button Bg Color', 'vw-education-lite'),
		'section'  => 'vw_education_lite_responsive_media',
	)));

    //Woocommerce settings
	$wp_customize->add_section('vw_education_lite_woocommerce_section', array(
		'title'    => __('WooCommerce Layout', 'vw-education-lite'),
		'priority' => null,
		'panel'    => 'woocommerce',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'vw_education_lite_woocommerce_shop_page_sidebar', array( 'selector' => '.post-type-archive-product .sidebar', 
		'render_callback' => 'vw_education_lite_customize_partial_vw_education_lite_woocommerce_shop_page_sidebar', ) );

	//Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'vw_education_lite_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Show / Hide Shop Page Sidebar','vw-education-lite' ),
		'section' => 'vw_education_lite_woocommerce_section'
    )));

    $wp_customize->add_setting('vw_education_lite_shop_page_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'vw_education_lite_sanitize_choices'
	));
	$wp_customize->add_control('vw_education_lite_shop_page_layout',array(
        'type' => 'select',
        'label' => __('Shop Page Sidebar Layout','vw-education-lite'),
        'section' => 'vw_education_lite_woocommerce_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-education-lite'),
            'Right Sidebar' => __('Right Sidebar','vw-education-lite'),
        ),
	) );

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'vw_education_lite_woocommerce_single_product_page_sidebar', array( 'selector' => '.single-product .sidebar', 
		'render_callback' => 'vw_education_lite_customize_partial_vw_education_lite_woocommerce_single_product_page_sidebar', ) );

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'vw_education_lite_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Show / Hide Single Product Sidebar','vw-education-lite' ),
		'section' => 'vw_education_lite_woocommerce_section'
    )));

    $wp_customize->add_setting('vw_education_lite_single_product_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'vw_education_lite_sanitize_choices'
	));
	$wp_customize->add_control('vw_education_lite_single_product_layout',array(
        'type' => 'select',
        'label' => __('Single Product Sidebar Layout','vw-education-lite'),
        'section' => 'vw_education_lite_woocommerce_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-education-lite'),
            'Right Sidebar' => __('Right Sidebar','vw-education-lite'),
        ),
	) );

	//Products per page
    $wp_customize->add_setting('vw_education_lite_products_per_page',array(
		'default'=> 9,
		'sanitize_callback'	=> 'vw_education_lite_sanitize_float'
	));
	$wp_customize->add_control('vw_education_lite_products_per_page',array(
		'label'	=> __('Products Per Page','vw-education-lite'),
		'description' => __('Display on shop page','vw-education-lite'),
		'input_attrs' => array(
            'step'             => 1,
			'min'              => 0,
			'max'              => 50,
        ),
		'section'=> 'vw_education_lite_woocommerce_section',
		'type'=> 'number',
	));

    //Products per row
    $wp_customize->add_setting('vw_education_lite_products_per_row',array(
		'default'=> 3,
		'sanitize_callback'	=> 'vw_education_lite_sanitize_choices'
	));
	$wp_customize->add_control('vw_education_lite_products_per_row',array(
		'label'	=> __('Products Per Row','vw-education-lite'),
		'description' => __('Display on shop page','vw-education-lite'),
		'choices' => array(
            2 => 2,
			3 => 3,
			4 => 4,
        ),
		'section'=> 'vw_education_lite_woocommerce_section',
		'type'=> 'select',
	));

	//Products padding
	$wp_customize->add_setting('vw_education_lite_products_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_products_padding_top_bottom',array(
		'label'	=> __('Products Padding Top Bottom','vw-education-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_education_lite_products_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_products_padding_left_right',array(
		'label'	=> __('Products Padding Left Right','vw-education-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_woocommerce_section',
		'type'=> 'text'
	));

	//Products box shadow
	$wp_customize->add_setting( 'vw_education_lite_products_box_shadow', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_education_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_education_lite_products_box_shadow', array(
		'label'       => esc_html__( 'Products Box Shadow','vw-education-lite' ),
		'section'     => 'vw_education_lite_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Products border radius
    $wp_customize->add_setting( 'vw_education_lite_products_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_education_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_education_lite_products_border_radius', array(
		'label'       => esc_html__( 'Products Border Radius','vw-education-lite' ),
		'section'     => 'vw_education_lite_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('vw_education_lite_products_btn_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_products_btn_padding_top_bottom',array(
		'label'	=> __('Products Button Padding Top Bottom','vw-education-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_education_lite_products_btn_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_products_btn_padding_left_right',array(
		'label'	=> __('Products Button Padding Left Right','vw-education-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_education_lite_products_button_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_education_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_education_lite_products_button_border_radius', array(
		'label'       => esc_html__( 'Products Button Border Radius','vw-education-lite' ),
		'section'     => 'vw_education_lite_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Products Sale Badge
	$wp_customize->add_setting('vw_education_lite_woocommerce_sale_position',array(
        'default' => 'right',
        'sanitize_callback' => 'vw_education_lite_sanitize_choices'
	));
	$wp_customize->add_control('vw_education_lite_woocommerce_sale_position',array(
        'type' => 'select',
        'label' => __('Sale Badge Position','vw-education-lite'),
        'section' => 'vw_education_lite_woocommerce_section',
        'choices' => array(
            'left' => __('Left','vw-education-lite'),
            'right' => __('Right','vw-education-lite'),
        ),
	) );

	$wp_customize->add_setting('vw_education_lite_woocommerce_sale_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_education_lite_woocommerce_sale_font_size',array(
		'label'	=> __('Sale Font Size','vw-education-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-education-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-education-lite' ),
        ),
		'section'=> 'vw_education_lite_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_education_lite_woocommerce_sale_border_radius', array(
		'default'              => '100',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_education_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_education_lite_woocommerce_sale_border_radius', array(
		'label'       => esc_html__( 'Sale Border Radius','vw-education-lite' ),
		'section'     => 'vw_education_lite_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

  	// Related Product
    $wp_customize->add_setting( 'vw_education_lite_related_product_show_hide',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_education_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Education_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_education_lite_related_product_show_hide',array(
        'label' => esc_html__( 'Show / Hide Related product','vw-education-lite' ),
        'section' => 'vw_education_lite_woocommerce_section'
    )));


    // Has to be at the top
	$wp_customize->register_panel_type( 'VW_Education_Lite_WP_Customize_Panel' );
	$wp_customize->register_section_type( 'VW_Education_Lite_WP_Customize_Section' );
    
}
add_action( 'customize_register', 'vw_education_lite_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo-resizer.php' );

if ( class_exists( 'WP_Customize_Panel' ) ) {
	class VW_Education_Lite_WP_Customize_Panel extends WP_Customize_Panel {
	    public $panel;
	    public $type = 'vw_education_lite_panel';
	    public function json() {

	      $array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'type', 'panel', ) );
	      $array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
	      $array['content'] = $this->get_content();
	      $array['active'] = $this->active();
	      $array['instanceNumber'] = $this->instance_number;
	      return $array;
	    }
  	}
}

if ( class_exists( 'WP_Customize_Section' ) ) {
  	class VW_Education_Lite_WP_Customize_Section extends WP_Customize_Section {
	    public $section;
	    public $type = 'vw_education_lite_section';
	    public function json() {

	      $array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'panel', 'type', 'description_hidden', 'section', ) );
	      $array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
	      $array['content'] = $this->get_content();
	      $array['active'] = $this->active();
	      $array['instanceNumber'] = $this->instance_number;

	      if ( $this->panel ) {
	        $array['customizeAction'] = sprintf( 'Customizing &#9656; %s', esc_html( $this->manager->get_panel( $this->panel )->title ) );
	      } else {
	        $array['customizeAction'] = 'Customizing';
	      }
	      return $array;
	    }
  	}
}

// Enqueue our scripts and styles
function vw_education_lite_customize_controls_scripts() {
	wp_enqueue_script( 'customizer-controls', get_theme_file_uri( '/js/customizer-controls.js' ), array(), '1.0', true );
}
add_action( 'customize_controls_enqueue_scripts', 'vw_education_lite_customize_controls_scripts' );

//Integer
function vw_education_lite_sanitize_integer( $input ) {
    if( is_numeric( $input ) ) {
        return absint( $input );
    }
}

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class VW_Education_Lite_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Education_Lite_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(new VW_Education_Lite_Customize_Section_Pro($manager,'vw_education_lite_upgrade_pro_link',array(
			'priority'	=> 1,
			'title'    => esc_html__( 'VW Education Pro', 'vw-education-lite' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'vw-education-lite' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/vw-education-theme/')
		)));

		$manager->add_section(new VW_Education_Lite_Customize_Section_Pro($manager,'vw_education_lite_get_started_link',array(
			'priority'	=> 1,
			'title'    => esc_html__( 'DOCUMENATATION', 'vw-education-lite' ),
			'pro_text' => esc_html__( 'DOCS',  'vw-education-lite' ),
			'pro_url'  => esc_url('https://preview.vwthemesdemo.com/docs/free-vw-education-lite/')
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-education-lite-customize-controls', trailingslashit( esc_url(get_template_directory_uri()) ) . '/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-education-lite-customize-controls', trailingslashit( esc_url(get_template_directory_uri()) ) . '/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
VW_Education_Lite_Customize::get_instance();